import base64
import subprocess
import uuid
import winreg

from cryptography.fernet import Fernet

# from hakisto import Logger
# logger = Logger('imuthes.crypt.win32')


__all__ = ["get_machine_user_fernet"]

__key = uuid.UUID(
    winreg.QueryValueEx(
        winreg.OpenKey(key=winreg.HKEY_LOCAL_MACHINE, sub_key=r"SOFTWARE\\Microsoft\\Cryptography\\"), "MachineGuid"
    )[0]
).bytes
__salt = uuid.UUID(
    int=int(subprocess.check_output("whoami /User").decode().split("\n")[6].split()[1][1:].replace("-", ""))
).bytes


def get_machine_user_fernet() -> Fernet:
    """Return Fernet object based on machine and user"""
    return Fernet(base64.urlsafe_b64encode(__key + __salt))



import pathlib
import click
from click_default_group import DefaultGroup
from .crypt import enigma

#from hakisto.click import hakisto_severity, hakisto_file

@click.group(context_settings=dict(help_option_names=["-h", "--help"]))
# @hakisto_severity()
# @hakisto_inline_location()
# @hakisto_short_trace()
@click.pass_context
def main(ctx, **kwargs):
    """Crypt utilities"""
    # hakisto_process_all(**kwargs)
    ctx.ensure_object(dict)


@main.group(
    cls=DefaultGroup,
    default="store",
    default_if_no_args=True,
)
@click.option("-f", "--file", type=click.Path(dir_okay=False, path_type=pathlib.Path), prompt=True)
@click.pass_context
def secret(ctx, file):
    """Locally stored secret"""
    ctx.obj["file"] = file


@secret.command()
@click.argument("phrase")
@click.pass_context
def store(ctx, phrase):
    """Store secret PHRASE"""
    with ctx.obj["file"].open("wb") as f:
        f.write(enigma(phrase))
